@@ -4,12 +4,12 @@ import re
 import subprocess
 import sys
 import tempfile
-from inspect import cleandoc
 
 from jogger.exceptions import TaskDefinitionError, TaskError
-from jogger.utils.output import OutputWrapper
+from jogger.utils.output import OutputWrapper, clean_doc_string
 
 TASK_NAME_RE = re.compile(r'^\w+$')
+DEFAULT_HELP_TEXT = 'No help text provided. Just guess?'
 
 #
 # The class-based "task" interface is heavily based on Django's management
@@ -291,12 +291,12 @@ class TaskProxy:
         elif isinstance(task, type) and issubclass(task, Task):
             self.exec_mode = 'python'
             self.executor = self.execute_class
-            self.help_text = task.help
+            self.help_text = task.help if task.help else DEFAULT_HELP_TEXT
             self.has_own_args = True
         elif callable(task):
             self.exec_mode = 'python'
             self.executor = self.execute_callable
-            self.help_text = cleandoc(task.__doc__) if task.__doc__ else ''
+            self.help_text = clean_doc_string(task.__doc__) if task.__doc__ else DEFAULT_HELP_TEXT
             self.has_own_args = False
         else:
             raise TaskDefinitionError(f'Unrecognised task format for "{name}".')
@@ -335,7 +335,13 @@ class TaskProxy:
             formatter_class=argparse.RawTextHelpFormatter
         )
         
-        return parser.parse_args(self.argv)
+        # If no explicit args are provided, use an empty string. This prevents
+        # parse_args() from using `sys.argv` as a default value, which is
+        # especially problematic if calling one task from within another (e.g.
+        # using Task.get_task_proxy()).
+        args = self.argv or ''
+        
+        return parser.parse_args(args)
     
     def execute(self):
         
