@@ -1,5 +1,6 @@
 import os
 import sys
+from inspect import cleandoc
 from io import TextIOBase
 
 #
@@ -16,6 +17,19 @@ OPTIONS = {'bold': '1', 'underscore': '4', 'blink': '5', 'reverse': '7', 'concea
 RESET = '\x1b[0m'
 
 
+def clean_doc_string(doc):
+    
+    # Clean up indentation
+    doc = cleandoc(doc)
+    
+    # Also remove superfluous newlines created by wrapping continuous lines.
+    # If newlines are desired in help text output, use *two* newlines in the
+    # docstring.
+    doc = doc.replace('\n\n', '\\N').replace('\n', ' ').replace('\\N', '\n')
+    
+    return doc
+
+
 class Styler:
     """
     An object containing methods for generating styled text for a palette of
